@@ -105,8 +105,8 @@ predict_wrapper.merMod <- function(model, newdata = NULL, ci = NULL, re.form = N
       type <- "linear.prediction"
     }
 
-    refgrid <- emmeans::ref_grid(model, at=as.list(newdata), data=newdata)
-    prediction <- as.data.frame(predict(refgrid, transform=transform, ci = ci, interval = interval))
+    refgrid <- emmeans::ref_grid(model, at = as.list(newdata), data = newdata)
+    prediction <- as.data.frame(predict(refgrid, transform = transform, ci = ci, interval = interval))
 
     # Clean
     prediction[names(newdata)] <- NULL
@@ -134,22 +134,27 @@ predict_wrapper.merMod <- function(model, newdata = NULL, ci = NULL, re.form = N
 #' @importFrom stats predict
 #' @keywords internal
 predict_wrapper.glmmTMB <- function(model, newdata = NULL, ci = NULL, re.form = NULL, transform = "response", ...) {
+  if (!is.null(re.form)) {
+    newdata[insight::find_variables(model, effects = "random")$random] <- NA
+  }
+
   if (is.null(ci)) {
     prediction <- data.frame(
       Predicted = stats::predict(model,
-                                 newdata = newdata,
-                                 re.form = re.form,
-                                 type = transform
+        newdata = newdata,
+        re.form = re.form,
+        type = transform
       ),
       CI_low = NA,
       CI_high = NA
     )
   } else {
     pr <- stats::predict(model,
-                         newdata = newdata,
-                         re.form = re.form,
-                         type = transform,
-                         se.fit = TRUE)
+      newdata = newdata,
+      re.form = re.form,
+      type = transform,
+      se.fit = TRUE
+    )
 
     ## TODO check if we need linkinverse
     if (transform != "zprob" && transform != "disp") {
@@ -172,19 +177,20 @@ predict_wrapper.gamm <- function(model, newdata = NULL, ci = 0.95, re.form = NUL
   if (is.null(ci)) {
     prediction <- data.frame(
       Predicted = stats::predict(model$gam,
-                                 newdata = newdata,
-                                 re.form = re.form,
-                                 type = transform
+        newdata = newdata,
+        re.form = re.form,
+        type = transform
       ),
       CI_low = NA,
       CI_high = NA
     )
   } else {
     pr <- stats::predict(model$gam,
-                         newdata = newdata,
-                         re.form = re.form,
-                         type = transform,
-                         se.fit = TRUE)
+      newdata = newdata,
+      re.form = re.form,
+      type = transform,
+      se.fit = TRUE
+    )
 
 
     prediction <- data.frame(
@@ -195,3 +201,6 @@ predict_wrapper.gamm <- function(model, newdata = NULL, ci = 0.95, re.form = NUL
   }
   prediction
 }
+
+#' @keywords internal
+predict_wrapper.list <- predict_wrapper.gamm  # gamm4
\ No newline at end of file
